#!/bin/bash
# knoppix-starttor
# Start/Stop vidalia GUI (if exists), or the tor daemon directly.
# (C) Klaus Knopper 2013
# License: GPL V2
# Requires: tor
# Suggests: vidalia

SMBTREE=""
TMP="/tmp/knoppix-starttor.$$.tmp"
ERR="$TMP.err"

bailout(){
 rm -f "$TMP" "$ERR"
 exit $1
}

trap bailout 3 10 15

case "$LANG" in
 de*) TITLE="TOR Proxy"; STARTTOR="TOR Proxy starten"; STARTVIDALIA="Vidalia (TOR GUI) starten"; STOPTOR="TOR Proxy beenden"; STOPVIDALIA="Vidalia (TOR GUI) und TOR beenden"; DONTSTART="Nicht starten"; STOPPED="Der TOR Proxy wurde beendet.\nBitte denken Sie daran, auch in Ihrem Browser die Proxy-Einstellungen zurückzusetzen."; FAILED="Fehler:"; STOP="TOR beenden"
      HELP_HTML='<big><b>TOR Info</b></big>\n\nTOR is ein anonymisierendes, kooperatives, weltweites Netzwerk von Proxy-Servern.\n\nDurch die Nutzung des TOR-Netzwerkes wird es den Betreibern von Webseiten und anderen Internet-Diensten erschwert, die tatsächliche Herkunft des Besuchers zu ermitteln.\n\nDer TOR-Dienst ist hier so vorkonfiguriert, dass Ihr eigener Rechner von anderen Nutzern des TOR-Netzwerkes allenfalls als Zwischenstartion in einer Reihe von Proxies, aber nicht als sichtbare "Exit-Node" verwendet werden kann.\n\nFür weitere Informationen lesen Sie bitte die <a href="http://de.wikipedia.org/wiki/Tor_(Netzwerk)">Wikipedia-Seite über das TOR-Netzwerk</a>.'
      HELP_AFTERSTART='<b>TOR wurde gestartet.</b>\n\nHINWEIS: Um Ihren TOR-Proxy nach dem Start auch tatsächlich zu verwenden,\naktivieren Sie bitte in Ihrem Browser (Firefox/Iceweasel oder Chromium)\nnoch den Proxy-Dienst mit Hilfe des Buttons neben der Adressleiste!\n\nEinige Browser-Plugins wie "torbutton" schalten bei aktiviertem TOR-Proxy\nstandardmäßig alle anderen Plugins ab. Dies lässt sich ggf. in den\nEinstellungen von "torbutton" ändern.'
      NOTINSTALLED="Das tor Paket ist nicht installiert."
      ;;
 *)   TITLE="TOR Proxy"; STARTTOR="Start TOR Proxy"; STARTVIDALIA="Start Vidalia (TOR GUI)"; STOPTOR="Stop TOR Proxy"; STOPVIDALIA="Stop Vidalia (TOR GUI) and TOR"; DONTSTART="Don't start"; STOPPED="TOR proxy terminated.\nPlease don't forget to unset the proxy in your browser."; FAILED="Error:"; STOP="Stop TOR"
      HELP_HTML='<big><b>TOR Info</b></big>\n\nTOR is an anonymizing, cooperative, worldwide network of proxy servers.\n\nUsing TOR makes it difficult for providers of websites and other internet services to track down the origin of the visitor.\n\nThis TOR server has been preconfigured to act only as intermediate proxy, if used by other TOR users, but never as visible "exit node".\n\nFor more information, please read the <a href="http://en.wikipedia.org/wiki/Tor_(anonymity_network)">Wikipedia page about the TOR network</a>.'
      HELP_AFTERSTART='<b>TOR has been started.</b>\n\nHINT: In order to really use your TOR proxy after start, please activate\nthe proxy service in your browser (Firefox/Iceweasel or Chromium) by\nclicking the proxy switcher button near the address field!\n\nPlease note that some browser extensions like "torbutton" will disable\nall other plugins when TOR is active. This can eventually be changed inside\nthe settings of "torbutton".'
      NOTINSTALLED="No tor package installed."
      ;;
esac

askstop(){
 zenity --title="$TITLE" --width=600 --height=200 --question --text="${STOPTOR}?" --ok-label="$STOP"
 return "$?"
}

askstart(){
 zenity --title="$TITLE" --width=600 --height=440 --question --text="$HELP_HTML" --ok-label="$START" --cancel-label="$DONTSTART"
 return "$?"
}

printstopped(){
 zenity --title="$TITLE" --timeout=10 --width=600 --height=200 --info --text="$STOPPED"
}

printstarted(){
 sleep 4; zenity --title="$TITLE" --no-wrap --width=600 --height=250 --info --text="$HELP_AFTERSTART"
}

printfailed(){
 zenity --title="$TITLE" --width=600 --height=440 --error --text="$FAILED\n$(cat $ERR 2>/dev/null)"
}

### MAIN
rm -f "$TMP" "$ERR"
if pidof -x vidalia >/dev/null 2>&1; then
 # Offer to stop vidalia
 STOP="$STOPVIDALIA"
 if askstop; then
  killall vidalia && sleep 4
  killall -x tor >/dev/null 2>&1
  printstopped
 fi
elif pidof -x tor >/dev/null 2>&1; then
 # Offer to stop tor
 STOP="$STOPTOR"
 if askstop; then
  sudo /etc/init.d/tor stop
  killall -x tor >/dev/null 2>&1
  printstopped
 fi
elif type -p vidalia >/dev/null 2>&1; then
 # Offer to start vidalia
 START="$STARTVIDALIA"
 if askstart; then
  if ( vidalia & ) >/dev/null 2>"$ERR"; then
   printstarted
  else
   printfailed
  fi
 fi
elif type -p tor >/dev/null 2>&1; then
 # Offer to start tor
 START="$STARTTOR"
 if askstart; then
  if sudo /etc/init.d/tor start 2>"$ERR"; then
   printstarted
  else
   printfailed
  fi
 fi
else
 # Error message
 echo "$NOTINSTALLED" >"$ERR"
 printfailed
 bailout 1
fi

bailout 0
